#!/bin/bash
##########   FoKoN 9.10   ###########\
# Intégration de poste Ubuntu 9.04   #
# dans un domaine Active Directory   #
# géré par IACA.                     #
#------------------------------------#
# Script : setup.sh                  #
# Collecte des renseignements néces- #
# saires à l'intégration.            #      
#------------------------------------#
# Auteur : Claude CLERC              #
# <claude.clerc@ac-aix-marseille.fr> #
# Site : http://www.fokon.org        #
# Licence : CeCILL - GPL 2.0         #
#####################################/

FOKONDIR=`dirname $0`	# Dossier de ce script.
# On intègre les vérifications d'usage:
. ${FOKONDIR}/common.sh

### Variables locales

# L'administrateur du domaine devrait renseigner le fichier 'constantes'
# afin de s'éviter de multiples saisies fastidieuses et sources d'erreurs.
# Insertion des constantes, si elles existent :
[ -f ${FOKONDIR}/constantes ] && {
	source ${FOKONDIR}/constantes
}
# Si les variables (données collectées par une exécution précédente de ce 
# script) existent, on les insère, et elles prennent le pas sur les constantes.
[ -f ${FOKONDIR}/variables ] && {
	source ${FOKONDIR}/variables
}

### Fonctions
function sortie() {
	(zenity --error --text="<big>Attention !</big>

Vous avez choisi d'interrompre la collecte de renseignements.

Ceux-ci sont forcéments incomplets, et il serait dangereux de poursuivre le processus d'intégration de ce poste dans le domaine, sans relancer à nouveau <b>$0</b>." --window-icon="/usr/share/icons/Human/24x24/status/gtk-dialog-error.png") && exit 1
}

function sortie_si_annule() {
	case $? in
		1 | -1 ) sortie ;;
		* ) return ;;
	esac
}

function mot_de_passe() {
	# Demande le mot de passe, avec confirmation si celui-ci a changé par rapport au précédent connu.
	# Entrées : mdp_TITRE et mdp_USER
	# Sortie : mdp_MDP2
	mdp_OK="0"
	while [[ "${mdp_OK}" = "0" ]]; do {
	# Mot de passe de l'admin de domaine
		mdp_MDP2=$(zenity --entry --title="${mdp_TITRE} - FoKoN ${VERSION_FOKON}" --text="Mot de passe de l'${mdp_USER} : " --entry-text="${mdp_MDP}" --hide-text)
		sortie_si_annule
		[ "${mdp_MDP}" = "${mdp_MDP2}" ] && {
			mdp_OK="1"
		}
		[ "${mdp_MDP}" = "${mdp_MDP2}" ] || {
			mdp_MDP3=$(zenity --entry --title="${mdp_TITRE} - FoKoN ${VERSION_FOKON}" --text="Confirmez le mot de passe de l'${mdp_USER} : " --entry-text="" --hide-text)
			sortie_si_annule
			[ "${mdp_MDP3}" = "${mdp_MDP2}" ] && {
				mdp_OK="1"
			}
		}
	}; done
	return
}

### Collecte de renseignements

# Nom d'hôte
OLDNOM=`hostname`
NOMPOSTE=$(zenity --entry --title="Nom de ce poste - FoKoN ${VERSION_FOKON}" --text="Ne renommez jamais un poste déjà inscrit dans le domaine, sans l'avoir auparavant sorti du domaine.
Ne donnez pas le même nom à deux postes distincts.

Les caractères autorisés pour le nom sont :
- les minuscules non accentuées (le premier caractère du nom doit en être une) ;
- les chiffres ;
- le caractère tiret (-)
Exemple : cdi-u01

Veuillez entrer le (nouveau) nom de cet ordinateur : " --entry-text="${OLDNOM}")
sortie_si_annule

# Architecture de ce poste
case ${ARCHI} in
	64 ) 
		BOOL_ARCHI32=="FALSE";
		BOOL_ARCHI64="TRUE";;
	32 ) 
		BOOL_ARCHI32=="TRUE";
		BOOL_ARCHI64="FALSE";;
esac
ARCHI2=$(zenity --list --radiolist --title="Architecture de l'ordinateur" --text="Ce poste a-t-il une architecture 32 ou 64 bits ? En cas de doute, choisissez 32." --column=" " --column="nb de bits" --print-column="2" \
${BOOL_ARCHI32} "32" \
${BOOL_ARCHI64} "64")
sortie_si_annule

# Nom de domaine
DOMAINE2=$(zenity --entry --title="Nom de domaine - FoKoN ${VERSION_FOKON}" --text="Exemple : ACARAVIGNON

Veuillez renseigner, en MAJUSCULES, le nom de domaine : " --entry-text="${DOMAINE}")
sortie_si_annule

# Id de l'admin de domaine
ADMIN_DOMAINE_ID2=$(zenity --entry --title="Administrateur du domaine - FoKoN ${VERSION_FOKON}" --text="Exemple : Administrateur

Identifiant de l'Administrateur du domaine : " --entry-text="${ADMIN_DOMAINE_ID}")
sortie_si_annule

# Mot de passe de l'admin de domaine
mdp_TITRE="Administrateur du domaine"
mdp_USER="Administrateur du domaine"
mdp_MDP=${ADMIN_DOMAINE_MDP}
mot_de_passe
ADMIN_DOMAINE_MDP2=${mdp_MDP2}

# Nom dns du domaine
[ -f /var/lib/dhcp3/dhclient.leases ] && {
	EXEMPLE_DOMAINE_NOM_DNS=`cat /var/lib/dhcp3/dhclient.leases | egrep -m 1 "domain-name " | awk '{print $3}' | sed s/"[\";]"//g`
	EXEMPLE_IP_PROXY=`cat /var/lib/dhcp3/dhclient.leases | egrep -m 1 "routers " | awk '{print $3}' | sed s/"[\";]"//g`
	EXEMPLE_IP_DNS=`cat /var/lib/dhcp3/dhclient.leases | egrep -m 1 "domain-name-servers " | awk '{print $3}' | sed s/"[\";]"//g`
	
}
[ -f /var/lib/dhcp3/dhclient.leases -o -z "${EXEMPLE_DOMAINE_NOM_DNS}" ] || {
	EXEMPLE_DOMAINE_NOM_DNS="in.acar-avignon.ac-aix-marseille.fr"
	EXEMPLE_IP_PROXY="172.0.0.245"
	EXEMPLE_IP_DNS="172.18.79.1"
}
DOMAINE_NOM_DNS2=$(zenity --entry --title="Nom DNS du domaine - FoKoN ${VERSION_FOKON}" --text="Exemple : ${EXEMPLE_DOMAINE_NOM_DNS}

Nom DNS du domaine : " --entry-text="${DOMAINE_NOM_DNS}")
sortie_si_annule

### Serveur IACA
# Nom du serveur IACA
SRVIACA_NOM2=$(zenity --entry --title="Nom du serveur IACA - FoKoN ${VERSION_FOKON}" --text="Exemple : iaca01

Nom du serveur IACA : " --entry-text="${SRVIACA_NOM}")
sortie_si_annule

# IP du serveur IACA
SRVIACA_IP2=$(zenity --entry --title="IP du serveur IACA - FoKoN ${VERSION_FOKON}" --text="Exemple : ${EXEMPLE_IP_DNS}

IP du serveur IACA : " --entry-text="${SRVIACA_IP}")
sortie_si_annule


### PROXY
# Nb de proxies nécessaires ?
case ${PROXY_NB} in
	0 | "" ) 
		BOOL_ZERO="TRUE";
		BOOL_UN="FALSE";
		BOOL_DEUX="FALSE";;
	1 ) 
		BOOL_ZERO="FALSE";
		BOOL_UN="TRUE";
		BOOL_DEUX="FALSE";;
	2 )
		BOOL_ZERO="FALSE";
		BOOL_UN="FALSE";
		BOOL_DEUX="TRUE";;
esac

PROXY_NB2=$(zenity --list --radiolist --title="Serveurs mandataires" --text="Combien avez-vous de  serveurs mandataires (<i>proxies</i>) pour accéder à Internet ?" --column=" " --column="Réponse" --column="Situation" --print-column="2" --separator="|" \
${BOOL_ZERO} "0" "Accès direct à Internet." \
${BOOL_UN} "1" "Un seul proxy, pour les utilisateurs comme pour le système (mises à jour, etc.)." \
${BOOL_DEUX} "2" "Un proxy utilisateurs + un proxy système")
sortie_si_annule


[ "${PROXY_NB2}" = "0" ] && {
	# Il n'y a pas de Proxy
	PROXY1_IP2=""
	PROXY1_PORT2=""
	PROXY1_ID2=""
	PROXY1_MDP2=""
	PROXY2_IP2=""
	PROXY2_PORT2=""
	PROXY2_ID2=""
	PROXY2_MDP2=""
}
[ "${PROXY_NB2}" = "0" ] || {
	# Il y a au moins un proxy
	AVANT_TITRE=""
	[ "${PROXY_NB2}" = "2" ] && {
		AVANT_TITRE="Premier"
	}
	# Proxy1 IP
	PROXY1_IP2=$(zenity --entry --title="${AVANT_TITRE} Serveur mandataire - FoKoN ${VERSION_FOKON}" --text="Exemple : ${EXEMPLE_IP_PROXY}

IP du proxy : " --entry-text="${PROXY1_IP}")
	sortie_si_annule

	# Proxy1 port
	PROXY1_PORT2=$(zenity --entry --title="${AVANT_TITRE} Serveur mandataire - FoKoN ${VERSION_FOKON}" --text="Exemples : 3128 ou 8080 ou 8181 ou ...

Port du proxy : " --entry-text="${PROXY1_PORT}")
	sortie_si_annule

	# Proxy1 user
	PROXY1_ID2=$(zenity --entry --title="${AVANT_TITRE} Serveur mandataire - FoKoN ${VERSION_FOKON}" --text="Laissez vide si le proxy ne nécessite pas d'identification.

Identifiant d'un utilisateur du proxy : " --entry-text="${PROXY1_ID}")
	sortie_si_annule

	# Proxy1 pwd (si identifiant renseigné)
	[ "${PROXY1_ID2}" = "" ] || {
		mdp_TITRE="${AVANT_TITRE} Serveur mandataire"
		mdp_USER="utilisateur ${PROXY1_ID2} du proxy"
		mdp_MDP=${PROXY1_MDP}
		mot_de_passe
		PROXY1_MDP2=${mdp_MDP2}
	}
	[ "${PROXY1_ID2}" = "" ] && {
		PROXY1_MDP2=""
	}
	# Second Proxy (si besoin)
	[ "${PROXY_NB2}" = "2" ] && {
		AVANT_TITRE="Second"
		# Proxy2 IP
		PROXY2_IP2=$(zenity --entry --title="${AVANT_TITRE} Serveur mandataire - FoKoN ${VERSION_FOKON}" --text="Exemple : proxy.monfai.com ou ${EXEMPLE_IP_PROXY}

IP du proxy système : " --entry-text="${PROXY2_IP}")
		sortie_si_annule

		# Proxy2 port
		PROXY2_PORT2=$(zenity --entry --title="${AVANT_TITRE} Serveur mandataire - FoKoN ${VERSION_FOKON}" --text="Exemples : 3128 ou 8080 ou 8181 ou ...

Port du proxy système : " --entry-text="${PROXY2_PORT}")
		sortie_si_annule

		# Proxy2 user
		PROXY2_ID2=$(zenity --entry --title="${AVANT_TITRE} Serveur mandataire - FoKoN ${VERSION_FOKON}" --text="Laissez vide si le proxy système ne nécessite pas d'identification.

Identifiant d'un utilisateur du proxy système : " --entry-text="${PROXY2_ID}")
		sortie_si_annule

		# Proxy2 pwd (si identifiant renseigné)
		[ "${PROXY2_ID2}" = "" ] || {
			mdp_TITRE="${AVANT_TITRE} Serveur mandataire"
			mdp_USER="utilisateur ${PROXY2_ID2} du proxy"
			mdp_MDP=${PROXY2_MDP}
			mot_de_passe
			PROXY2_MDP2=${mdp_MDP2}
		}
		[ "${PROXY2_ID2}" = "" ] && {
			PROXY2_MDP2=""
		}
	}
}

### Serveur DNS
BOOL_PROXY="FALSE"
BOOL_IACA="FALSE"
BOOL_AUTRE="FALSE"
[ -z ${DNS_IP} ] || {
	case "${DNS_IP}" in
		"${PROXY1_IP2}" ) BOOL_PROXY="TRUE" ;;
		"${SRVIACA_IP2}" ) BOOL_IACA="TRUE" ;;
		* ) BOOL_AUTRE="TRUE" ;;
	esac
}
CHOIX_DNS=$(zenity --list --radiolist --title="Serveur DNS - FoKoN ${VERSION_FOKON}" --text="Quelle est l'IP du serveur DNS primaire ?" --column=" " --column="Nom" --column="IP" --print-column="2" \
${BOOL_PROXY} "Proxy" "${PROXY1_IP2}" \
${BOOL_IACA} "${SRVIACA_NOM2}" "${SRVIACA_IP2}" \
${BOOL_AUTRE} "Autre" "${DNS_IP} ? (à confirmer par la suite)")
sortie_si_annule


case "$CHOIX_DNS" in
	"Proxy" ) DNS_IP2=${PROXY1_IP2} ;;
	"${SRVIACA_NOM2}" ) DNS_IP2=${SRVIACA_IP2} ;;
	"Autre" ) DNS_IP2=$(zenity --entry --title="Serveur DNS - FoKoN ${VERSION_FOKON}" --text="Exemple : 172.0.0.245

Entrez ou confirmez l'IP du proxy : " --entry-text="${DNS_IP}"); sortie_si_annule ;;
esac

 
### Configuration du Proxy (ou des Proxies)
[ "${PROXY_NB2}" = "0" ] && {
	USE_PROXY="off"
}
[ "${PROXY_NB2}" = "0" ] || {
	USE_PROXY="on"
	case "${PROXY_NB2}" in
		"1" ) 
			STR_PROXY_USR=""	# Proxy utilisateurs.
			STR_PROXY_SYS=""	# Proxy système.
			PROXY_SYS_USER=""
			PROXY_SYS_PASSWD=""
			[ -z ${PROXY1_ID} ] || {
				# Identification requise (proxy système uniquement) :
				STR_PROXY_SYS="${STR_PROXY_SYS}${PROXY1_ID}"
				PROXY_SYS_USER="${PROXY1_ID}"
				[ -z ${PROXY1_MDP} ] || {
					# Authentification requise (proxy système uniquement) :
					STR_PROXY_SYS="${STR_PROXY_SYS}:${PROXY1_MDP}"
					PROXY_SYS_PASSWD=${PROXY1_MDP}
				}
				STR_PROXY_SYS="${STR_PROXY_SYS}@"	# structure : "id:mdp@"
			}
			[ -z ${PROXY1_IP} ] && { 
				echo "Erreur de configuration : IP de proxy non indiquée !"
				exit 1
			}
			STR_PROXY_USR="${STR_PROXY_USR}${PROXY1_IP}"
			[ -z ${PROXY1_PORT} ] || {
				STR_PROXY_USR="${STR_PROXY_USR}:${PROXY1_PORT}"
			}
			STR_PROXY_USR="${STR_PROXY_USR}/"	# Le fameux slash final !
			STR_PROXY_SYS="${STR_PROXY_SYS}${STR_PROXY_USR}"
			STR_PROXY_USR="http://${STR_PROXY_USR}"	# structure : "http://ip[:port]/"
			STR_PROXY_SYS="http://${STR_PROXY_SYS}"	# structure : "http://[id[:mdp]]@ip[:port]/"
		;;
		"2" ) # Proxy système :
			STR_PROXY_USR=""	# Proxy utilisateurs.
			STR_PROXY_SYS=""	# Proxy système.
			PROXY_SYS_USER=""
			PROXY_SYS_PASSWD=""
			[ -z ${PROXY1_IP} ] && { 
				echo "Erreur de configuration : IP de proxy non indiquée !"
				exit 1
			}
			STR_PROXY_USR="${STR_PROXY_USR}${PROXY1_IP}"
			[ -z ${PROXY1_PORT} ] || {
				STR_PROXY_USR="${STR_PROXY_USR}:${PROXY1_PORT}"
			}
			STR_PROXY_USR="${STR_PROXY_USR}/"	# Le fameux slash final !
			#STR_PROXY_SYS="${STR_PROXY_SYS}${STR_PROXY_USR}"
			STR_PROXY_USR="http://${STR_PROXY_USR}"	# structure : "http://ip[:port]/"
			#STR_PROXY_SYS="http://${STR_PROXY_SYS}"	# structure : "http://[id[:mdp]]@ip[:port]/"


			[ -z ${PROXY2_ID} ] || {
				# Identification requise (proxy système uniquement) :
				STR_PROXY_SYS="${STR_PROXY_SYS}${PROXY2_ID}"
				PROXY_SYS_USER="${PROXY2_ID}"
				[ -z ${PROXY2_MDP} ] || {
					# Authentification requise (proxy système uniquement) :
					STR_PROXY_SYS="${STR_PROXY_SYS}:${PROXY2_MDP}"
					PROXY_SYS_PASSWD=${PROXY2_MDP}
				}
				STR_PROXY_SYS="${STR_PROXY_SYS}@"	# structure : "id:mdp@"
			}
			[ -z ${PROXY2_IP} ] && { 
				echo "Erreur de configuration : IP de proxy système non indiquée !"
				exit 1
			}
			STR_PROXY_SYS="${STR_PROXY_SYS}${PROXY2_IP}"
			[ -z ${PROXY2_PORT} ] || {
				STR_PROXY_SYS="${STR_PROXY_SYS}:${PROXY2_PORT}"
			}
			STR_PROXY_SYS="http://${STR_PROXY_SYS}/"	# structure : "http://[id[:mdp]]@ip[:port]/"
		;;
	esac
}


# Inscription des données collectées dans le fichier 'variables'
#rm -f ${FOKONDIR}/variables
#touch ${FOKONDIR}/variables
(
echo "NOMPOSTE=\"${NOMPOSTE}\""
echo "ARCHI=\"${ARCHI2}\""
echo "DOMAINE=\"${DOMAINE2}\""
echo "ADMIN_DOMAINE_ID=\"${ADMIN_DOMAINE_ID2}\""
echo "ADMIN_DOMAINE_MDP=\"${ADMIN_DOMAINE_MDP2}\""
echo "DOMAINE_NOM_DNS=\"${DOMAINE_NOM_DNS2}\""
echo "PROXY_NB=\"${PROXY_NB2}\""
echo "PROXY1_IP=\"${PROXY1_IP2}\""
echo "PROXY1_PORT=\"${PROXY1_PORT2}\""
echo "PROXY1_ID=\"${PROXY1_ID2}\""
echo "PROXY1_MDP=\"${PROXY1_MDP2}\""
echo "PROXY2_IP=\"${PROXY2_IP2}\""
echo "PROXY2_PORT=\"${PROXY2_PORT2}\""
echo "PROXY2_ID=\"${PROXY2_ID2}\""
echo "PROXY2_MDP=\"${PROXY2_MDP2}\""
echo "USE_PROXY=\"${USE_PROXY}\""
echo "STR_PROXY_USR=\"${STR_PROXY_USR}\""
echo "STR_PROXY_SYS=\"${STR_PROXY_SYS}\""
echo "PROXY_SYS_USER=\"${PROXY_SYS_USER}\""
echo "PROXY_SYS_PASSWD=\"${PROXY_SYS_PASSWD}\""
echo "SRVIACA_NOM=\"${SRVIACA_NOM2}\""
echo "SRVIACA_IP=\"${SRVIACA_IP2}\""
echo "DNS_IP=\"${DNS_IP2}\""
) >  ${FOKONDIR}/variables
#chmod 600 ${FOKONDIR}/variables

RECAPITULATIF=`cat ${FOKONDIR}/variables | egrep -v "_MDP|STR_PROXY_|PROXY_SYS_"`

# Recommencer ?
RECOMMENCER=$(zenity --list --radiolist --title="Fin de saisie - FoKoN ${VERSION_FOKON}" --text="Les renseignements collectés ont été placés dans le fichier :
${FOKONDIR}/variables

Sans affichage des mots de passe, cela donne ceci :
${RECAPITULATIF}

Voulez-vous recommencer la collecte de renseignements ?" --column=" " --column="Recommencer ?" --print-column="2" \
FALSE "oui" \
TRUE "non")
[ "$RECOMMENCER" = "oui" ] && {
	$0
	exit 0
}

INTEGRER=$(zenity --list --radiolist --title="Intégration au domaine - FoKoN ${VERSION_FOKON}" --text="Êtes-vous prêt à intégrer ce poste ${NOMPOSTE} au domaine ${DOMAINE2} ?" --column=" " --column="Intégrer ?" --print-column="2" \
FALSE "oui" \
TRUE "non")
[ "$INTEGRER" = "oui" ] && {
	${FOKONDIR}/setup2.sh
}
exit 0

